@@ -17,8 +17,8 @@ def test_is_txt_record_quoted(value: str, expected: bool):
     assert is_txt_record_quoted(value) == expected
 
 
-manyA = "a" * 255
-someB = "b" * 10
+MANY_A = "a" * 255
+SOME_B = "b" * 10
 
 
 @pytest.mark.parametrize(
@@ -30,7 +30,7 @@ someB = "b" * 10
         ("hello\nworld", '"hello\nworld"'),
         ('hello "world"', '"hello \\"world\\""'),
         ('hello "world', '"hello \\"world"'),
-        (manyA + someB, f'"{manyA}" "{someB}"'),
+        (MANY_A + SOME_B, f'"{MANY_A}" "{SOME_B}"'),
     ],
 )
 def test_format_txt_record(value: str, expected: str):
